@@ -59,23 +59,21 @@ def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent'), headers={
 
 def safe_put_simple_url(url, log=logging.getLogger('spotinst-agent'), headers={}):
     ret_val = None
-    
+
     try:
         log.debug("reading simple {} ...".format(url))
-        req = Request(url, headers=headers, method='PUT')
-        req.add_header('Content-Type', 'application/json')
+        req = Request(url, headers=headers)
+        req.get_method = lambda: 'PUT'
         response = urlopen(req, timeout=10)
 
-        if response.status_code == 200:
+        if response.code == 200:
             ret_val = response.read().decode('utf-8')
-        else:
-            log.warn("Filed to retrieve token")
     except HTTPError as e:
-        log.error("The server can't fulfill the GET {} request. [reason: {}]".format(url, e.reason))
+        log.error("The server can't fulfill the PUT {} request. [reason: {}]".format(url, e.reason))
     except URLError as e:
-        log.error("Unable to reach the server for GET request. [reason: {}]".format(e.reason))
+        log.error("Unable to reach the server for PUT request. [reason: {}]".format(e.reason))
     except Exception as e:
-        log.error("There was an error of GET url {}: {}".format(url, e.__str__()))
+        log.error("There was an error of PUT url {}: {}".format(url, e.__str__()))
     finally:
         try:
             response.close()
@@ -206,11 +204,11 @@ def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agen
             pass
 
 
-def safe_put_url(url, message, token, log=logging.getLogger('spotinst-agent'), headers={}):
+def safe_put_url(url, message, token, log=logging.getLogger('spotinst-agent')):
     try:
         log.debug("putting %s ..." % url)
         data = message.encode('utf-8')
-        req = Request(url, headers=headers)
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
